@@ -73,6 +73,77 @@ hbjson_model_grid_input = [
 ]
 
 
+"""Alias inputs that expect a HBJSON model with sensor grids and rooms."""
+hbjson_model_grid_room_input = [
+    # grasshopper Alias
+    InputAlias.any(
+        name='model',
+        description='A Honeybee Model to simulate or the path to a HBJSON file '
+        'of a Model. Note that this model must contain rooms and have sensor '
+        'grids assigned to it.',
+        platform=['grasshopper'],
+        handler=[
+            IOAliasHandler(
+                language='python', module='pollination_handlers.inputs.model',
+                function='model_to_json_grid_room_check'
+            ),
+            IOAliasHandler(
+                language='csharp', module='Pollination.RhinoHandlers',
+                function='HBModelToJSON'
+            )
+        ]
+    ),
+    # Rhino alias
+    InputAlias.linked(
+        name='model',
+        description='This input links the model to Rhino model.',
+        platform=['rhino'],
+        handler=[
+            IOAliasHandler(
+                language='csharp', module='Pollination.RhinoHandlers',
+                function='RhinoHBModelToJSON'
+            )
+        ]
+    )
+]
+
+
+"""Alias inputs that expect a HBJSON model with views."""
+hbjson_model_view_input = [
+    # grasshopper Alias
+    InputAlias.any(
+        name='model',
+        description='A Honeybee Model to simulate or the path to a HBJSON file '
+        'of a Model. This can also be the path to a HBpkl file, though this is only '
+        'recommended for cases where the model is extremely large. Note that this '
+        'model should have views assigned to it.',
+        platform=['grasshopper'],
+        handler=[
+            IOAliasHandler(
+                language='python', module='pollination_handlers.inputs.model',
+                function='model_to_json_view_check'
+            ),
+            IOAliasHandler(
+                language='csharp', module='Pollination.RhinoHandlers',
+                function='HBModelToJSON'
+            )
+        ]
+    ),
+    # Rhino alias
+    InputAlias.linked(
+        name='model',
+        description='This input links the model to Rhino model.',
+        platform=['rhino'],
+        handler=[
+            IOAliasHandler(
+                language='csharp', module='Pollination.RhinoHandlers',
+                function='RhinoHBModelToJSON'
+            )
+        ]
+    )
+]
+
+
 """Alias inputs that expect a HBJSON model with views."""
 hbjson_model_view_input = [
     # grasshopper Alias
